#!/usr/bin/gawk -f

BEGIN{
  pi = 3.1415926535;
  deg = pi/180.;
  mas = 1.e-3;  # arcsec
  OFMT=CONVFMT="%.6f";
}
(ARGIND==1) && !/^#/{
  jd = $1;
  u[jd] = $2*mas;
  v[jd] = $3*mas;
}
(ARGIND>1) && /^#/{
  print;
}
(ARGIND>1) && !/^#/{
  jd = $1;
  sep = $2;
  ang = $3*deg;
  major = $4;
  minor = $5;
  PA_ellipse = $6;
  d = $7;
  l_ = $8;
  b = $9;
  bessel = $10;
  dataset = $11;

  x = -sep*sin(ang);
  y = sep*cos(ang);

  found = 0;
  if (jd in u) {
    x = x + u[jd];
    y = y + v[jd];
    found = 1;
  } else {
    for (jd_ in u) {
      if ((abs(jd-jd_) < 0.02) && (found==0)) {
        x = x + u[jd_];
        y = y + v[jd_];
#        print "# jd = ", jd, " close to jd' = ", jd_;
        found = 1;
      }
    }
  }
  if (found==0) {
    print "# jd = ", jd, " NOT CORRECTED!";
  }

  sep = sqrt(x**2+y**2);
  ang = -atan2(x,y);
  if (ang < 0.0) { ang = ang + 2.*pi; }

  print jd "	" sep "	" ang/deg "	" major "	" minor "	" PA_ellipse "	" d "	" l_ "	" b "	"  bessel "	" dataset;
}

func abs(x) {
  if (x > 0) {
    return x;
  } else {
    return -x;
  }
}

